<?php

namespace Tests\Feature;

use Illuminate\Support\Str;
use Laravel\Sanctum\Sanctum;
use Tests\TestCase;
use App\Models\User;
use App\Models\Category;
use Hash;

class CategoryDeleteTest extends TestCase
{
    public function test_success_delete_category_by_admin()
    {
        $user = User::factory()->create([
            'role' => 'admin',
            'password' => Hash::make('123123123'),
        ]);
        $category = Category::factory()->create();
        Sanctum::actingAs(
            $user,
            ['*']
        );
        $response = $this->delete('nova-api/categories?filters=W10%3D&resources[]='.$category->id);
        $user->delete();
        $response->assertStatus(200);
    }

    public function test_success_delete_category_by_analyst()
    {
        $user = User::factory()->create([
            'role' => 'analyst',
            'password' => Hash::make('123123123'),
        ]);
        $category = Category::factory()->create();
        Sanctum::actingAs(
            $user,
            ['*']
        );
        $response = $this->delete('nova-api/categories?filters=W10%3D&resources[]='.$category->id);
        $user->delete();
        $response->assertStatus(200);
    }

    public function test_delete_category_by_common()
    {
        $user = User::factory()->create([
            'role' => 'common',
            'password' => Hash::make('123123123'),
        ]);
        Sanctum::actingAs(
            $user,
            ['*']
        );
        $category = Category::factory()->create();
        $response = $this->delete('nova-api/categories?filters=W10%3D&resources[]='.$category->id);
        $category->delete();
        $user->delete();
        $response->assertStatus(403);
    }

    public function test_update_category_by_unauthenticate_user()
    {
        $category = Category::factory()->create();
        $response = $this->delete('nova-api/categories?filters=W10%3D&resources[]='.$category->id);
        $category->delete();
        $response->assertStatus(401);
    }
}